@@ -25,12 +25,10 @@ impl std::fmt::Debug for Headers {
     }
 }
 
-#[allow(clippy::new_without_default)]
 impl Headers {
     /// Construct a new `Headers` struct.
     pub fn new() -> Self {
-        // This cannot throw an error: https://developer.mozilla.org/en-US/docs/Web/API/Headers/Headers
-        Headers(EdgeHeaders::new().unwrap())
+        Default::default()
     }
 
     /// Returns all the values of a header within a `Headers` object with a given name.
@@ -101,6 +99,13 @@ impl Headers {
     }
 }
 
+impl Default for Headers {
+    fn default() -> Self {
+        // This cannot throw an error: https://developer.mozilla.org/en-US/docs/Web/API/Headers/Headers
+        Headers(EdgeHeaders::new().unwrap())
+    }
+}
+
 type F1 = fn(StdResult<JsValue, JsValue>) -> Array;
 type HeaderIterator = Map<Map<js_sys::IntoIter, F1>, fn(Array) -> (String, String)>;
 
