@@ -3,6 +3,7 @@
 
 mod cf;
 mod context;
+mod cors;
 mod date;
 pub mod durable;
 mod env;
@@ -16,6 +17,7 @@ mod request_init;
 mod response;
 mod router;
 mod schedule;
+mod websocket;
 
 #[doc(hidden)]
 use std::result::Result as StdResult;
@@ -23,6 +25,7 @@ use std::result::Result as StdResult;
 pub type Result<T> = StdResult<T, error::Error>;
 
 pub use crate::context::Context;
+pub use crate::cors::Cors;
 pub use crate::date::{Date, DateInit};
 pub use crate::env::Env;
 pub use crate::error::Error;
@@ -35,6 +38,7 @@ pub use crate::request_init::*;
 pub use crate::response::{Response, ResponseBody};
 pub use crate::router::{RouteContext, RouteParams, Router};
 pub use crate::schedule::*;
+pub use crate::websocket::*;
 pub use cf::Cf;
 pub use url::Url;
 
