@@ -1,6 +1,5 @@
 use crate::{cf::Cf, error::Error, headers::Headers, http::Method, FormData, RequestInit, Result};
 
-use js_sys;
 use serde::de::DeserializeOwned;
 use url::Url;
 use wasm_bindgen_futures::JsFuture;
@@ -8,6 +7,7 @@ use worker_sys::{Request as EdgeRequest, RequestInit as EdgeRequestInit};
 
 /// A [Request](https://developer.mozilla.org/en-US/docs/Web/API/Request) representation for
 /// handling incoming and creating outbound HTTP requests.
+#[derive(Debug)]
 pub struct Request {
     method: Method,
     path: String,
@@ -145,7 +145,7 @@ impl Request {
         Err(Error::BodyUsed)
     }
 
-    /// Get the `Headers` for this reuqest.
+    /// Get the `Headers` for this request.
     pub fn headers(&self) -> &Headers {
         &self.headers
     }
@@ -176,6 +176,17 @@ impl Request {
         self.path.clone()
     }
 
+    /// Get a mutable reference to this request's path.
+    /// **Note:** they can only be modified if the request was created from scratch or cloned.
+    pub fn path_mut(&mut self) -> Result<&mut String> {
+        if self.immutable {
+            return Err(Error::JsError(
+                "Cannot get a mutable reference to an immutable path.".into(),
+            ));
+        }
+        Ok(&mut self.path)
+    }
+
     /// The parsed [`url::Url`] of this `Request`.
     pub fn url(&self) -> Result<Url> {
         let url = self.edge_request.url();
