@@ -1,11 +1,13 @@
+use crate::cors::Cors;
 use crate::error::Error;
 use crate::headers::Headers;
 use crate::Result;
+use crate::WebSocket;
 
 use js_sys::Uint8Array;
 use serde::{de::DeserializeOwned, Serialize};
 use wasm_bindgen_futures::JsFuture;
-use worker_sys::{Response as EdgeResponse, ResponseInit as EdgeResponseInit};
+use worker_sys::{response_init::ResponseInit as EdgeResponseInit, Response as EdgeResponse};
 
 #[derive(Debug)]
 pub enum ResponseBody {
@@ -23,6 +25,7 @@ pub struct Response {
     body: ResponseBody,
     headers: Headers,
     status_code: u16,
+    websocket: Option<WebSocket>,
 }
 
 impl Response {
@@ -37,6 +40,7 @@ impl Response {
                 body: ResponseBody::Body(data.into_bytes()),
                 headers,
                 status_code: 200,
+                websocket: None,
             });
         }
 
@@ -54,6 +58,7 @@ impl Response {
             body: ResponseBody::Body(data),
             headers,
             status_code: 200,
+            websocket: None,
         })
     }
 
@@ -67,16 +72,29 @@ impl Response {
             body: ResponseBody::Body(bytes),
             headers,
             status_code: 200,
+            websocket: None,
         })
     }
 
-    // Create a `Response` using a `ResponseBody` variant. Sets a status code of 200 and an empty
-    // set of Headers. Modify the Response with methods such as `with_status` and `with_headers`.
+    /// Create a `Response` using a `ResponseBody` variant. Sets a status code of 200 and an empty
+    /// set of Headers. Modify the Response with methods such as `with_status` and `with_headers`.
     pub fn from_body(body: ResponseBody) -> Result<Self> {
         Ok(Self {
             body,
             headers: Headers::new(),
             status_code: 200,
+            websocket: None,
+        })
+    }
+
+    /// Create a `Response` using a `WebSocket` client. Configures the browser to switch protocols
+    /// (using status code 101) and returns the websocket.
+    pub fn from_websocket(websocket: WebSocket) -> Result<Self> {
+        Ok(Self {
+            body: ResponseBody::Empty,
+            headers: Headers::new(),
+            status_code: 101,
+            websocket: Some(websocket),
         })
     }
 
@@ -90,6 +108,7 @@ impl Response {
             body: ResponseBody::Body(body.into().into_bytes()),
             headers,
             status_code: 200,
+            websocket: None,
         })
     }
 
@@ -99,6 +118,7 @@ impl Response {
             body: ResponseBody::Empty,
             headers: Headers::new(),
             status_code: 200,
+            websocket: None,
         })
     }
 
@@ -115,6 +135,7 @@ impl Response {
             body: ResponseBody::Body(msg.into().into_bytes()),
             headers: Headers::new(),
             status_code: status,
+            websocket: None,
         })
     }
 
@@ -179,6 +200,11 @@ impl Response {
         }
     }
 
+    // Get the WebSocket returned by the the server.
+    pub fn websocket(self) -> Option<WebSocket> {
+        self.websocket
+    }
+
     /// Set this response's `Headers`.
     pub fn with_headers(mut self, headers: Headers) -> Self {
         self.headers = headers;
@@ -193,6 +219,29 @@ impl Response {
         self
     }
 
+    /// Sets this response's cors headers from the `Cors` struct.
+    /// Example usage:
+    /// ```
+    /// use worker::*;
+    /// fn fetch() -> worker::Result<Response> {
+    ///     let cors = Cors::default();
+    ///     Response::empty()?
+    ///         .with_cors(&cors)
+    /// }
+    /// ```
+    pub fn with_cors(self, cors: &Cors) -> Result<Self> {
+        let mut headers = self.headers.clone();
+        cors.apply_headers(&mut headers)?;
+        Ok(self.with_headers(headers))
+    }
+
+    /// Sets this response's `webSocket` option.
+    /// This will require a status code 101 to work.
+    pub fn with_websocket(mut self, websocket: Option<WebSocket>) -> Self {
+        self.websocket = websocket;
+        self
+    }
+
     /// Read the `Headers` on this response.
     pub fn headers(&self) -> &Headers {
         &self.headers
@@ -214,6 +263,7 @@ fn no_using_invalid_error_status_code() {
 pub struct ResponseInit {
     pub status: u16,
     pub headers: Headers,
+    pub websocket: Option<WebSocket>,
 }
 
 impl From<ResponseInit> for EdgeResponseInit {
@@ -221,6 +271,9 @@ impl From<ResponseInit> for EdgeResponseInit {
         let mut edge_init = EdgeResponseInit::new();
         edge_init.status(init.status);
         edge_init.headers(&init.headers.0);
+        if let Some(websocket) = &init.websocket {
+            edge_init.websocket(websocket.as_ref());
+        }
         edge_init
     }
 }
@@ -237,6 +290,7 @@ impl From<Response> for EdgeResponse {
                     &ResponseInit {
                         status: res.status_code,
                         headers: res.headers,
+                        websocket: res.websocket,
                     }
                     .into(),
                 )
@@ -247,6 +301,7 @@ impl From<Response> for EdgeResponse {
                 &ResponseInit {
                     status: res.status_code,
                     headers: res.headers,
+                    websocket: res.websocket,
                 }
                 .into(),
             )
@@ -256,6 +311,7 @@ impl From<Response> for EdgeResponse {
                 &ResponseInit {
                     status: res.status_code,
                     headers: res.headers,
+                    websocket: res.websocket,
                 }
                 .into(),
             )
@@ -269,6 +325,7 @@ impl From<EdgeResponse> for Response {
         Self {
             headers: Headers(res.headers()),
             status_code: res.status(),
+            websocket: res.websocket().map(|ws| ws.into()),
             body: match res.body() {
                 Some(_) => ResponseBody::Stream(res),
                 None => ResponseBody::Empty,
